# RaiPlaySound - Podcast non ufficiale

Questa pagina è solo per chi vuole smanettare, altrimenti il lavoro è già fatto. In ogni caso...

## Vai su http://timendum.github.io/raiplaysound/

### FAQ

#### Non trovo il programma che mi interessa

Dall'elenco generato e disponibile [qui](https://timendum.github.io/raiplaysound/),
sono esclusi i programmi quotidiani e le audiodescrizioni dei film.

Controlla se quello che ti interessa rientra in questa categoria.  
In caso positivo, questo software funziona comunque,
puoi installarlo ed ottenere il programma che ti interessa seguendo
le istruzioni in [questa sezione](https://timendum.github.io/raiplaysound/#diy).

#### Dal podcast mancano gli ultimi episodi

Aggiorno i podcast ogni tanto, se sono passati vari mesi, apri pure una issue.

Se hai fretta o vuoi un podcast sempre aggiornato,
il consiglio è quello di [fare da solo](https://timendum.github.io/raiplaysound/#diy).

#### Ho fatto girare il software, ma la mia lista è più piccola

Capita, ogni tanto dal sito scompaiono dei programmi e quindi il software non lo estrae più.

Io faccio girare il software dove ho i file dell'esecuzione precedente,
in modo da mantenere i singoli file di podcast (anche se non più aggiornati).